==> react-form-builder-4.5.0.tgz: package/lib/Standard/Fields/Picker/index.js <==
import React from 'react';
import PropTypes from 'prop-types';
import Switch from '../../../Switch';
import Select from '../../../Select';
import Checkbox from '../../../Checkbox';
import InlineButton from '../../../InlineButton';
import Radio from '../../../Radio';
import { FIELDS, DISPLAYS } from '../../index';

var PickerField = function PickerField(_ref) {
  var field = _ref.field,
      tabIndex = _ref.tabIndex,
      onChange = _ref.onChange,
      onBlur = _ref.onBlur,
      errors = _ref.errors,
      alerts = _ref.alerts,
      renderer = _ref.renderer;

  if (field.display === DISPLAYS[FIELDS.PICKER].SWITCH) {
    return React.createElement(Switch, {
      switchField: field,
      onChange: onChange,
      onBlur: onBlur,
      tabIndex: tabIndex,
      errors: errors,
      alerts: alerts,
      renderer: renderer
    });
  } else if (field.display === DISPLAYS[FIELDS.PICKER].AUTOCOMPLETE || field.display === DISPLAYS[FIELDS.PICKER].DROPDOWN) {
    return React.createElement(Select, {
      select: field,
      onChange: onChange,
      onBlur: onBlur,
      tabIndex: tabIndex,
      errors: errors,
      alerts: alerts,
      renderer: renderer
    });
  } else if (field.display === DISPLAYS[FIELDS.PICKER].RADIO) {
    return React.createElement(Radio, {
      radio: field,
      onChange: onChange,
      onBlur: onBlur,
      tabIndex: tabIndex,
      errors: errors,
      alerts: alerts,
      renderer: renderer
    });
  } else if (field.display === DISPLAYS[FIELDS.PICKER].CHECKBOX) {
    return React.createElement(Checkbox, {
      checkbox: field,
      onChange: onChange,
      onBlur: onBlur,
      tabIndex: tabIndex,
      errors: errors,
      alerts: alerts,
      renderer: renderer
    });
  } else if (field.display === DISPLAYS[FIELDS.PICKER].BUTTON_INLINE) {
    return React.createElement(InlineButton, {
      inlineButton: field,
      onChange: onChange,
      onBlur: onBlur,
      tabIndex: tabIndex,
      errors: errors,
      alerts: alerts,
      renderer: renderer
    });
  } else {
    // TODO: should be removed (backwards compatibility)
    return React.createElement(Select, {
      select: field,
      onChange: onChange,
      onBlur: onBlur,
      tabIndex: tabIndex,
      errors: errors,
      alerts: alerts,
      renderer: renderer
    });
  }
};

export default PickerField;

==> react-form-builder-4.9.0.tgz: package/lib/Standard/Fields/Picker/index.js <==
import { jsx as _jsx } from "react/jsx-runtime";
import Switch from '../../../Switch';
import Select from '../../../Select';
import Checkbox from '../../../Checkbox';
import InlineButton from '../../../InlineButton';
import Radio from '../../../Radio';
import { FIELDS, DISPLAYS } from '../../index';

var PickerField = function PickerField(_ref) {
  var field = _ref.field,
      tabIndex = _ref.tabIndex,
      onChange = _ref.onChange,
      onBlur = _ref.onBlur,
      errors = _ref.errors,
      alerts = _ref.alerts,
      renderer = _ref.renderer;

  if (field.display === DISPLAYS[FIELDS.PICKER].SWITCH) {
    return /*#__PURE__*/_jsx(Switch, {
      switchField: field,
      onChange: onChange,
      onBlur: onBlur,
      tabIndex: tabIndex,
      errors: errors,
      alerts: alerts,
      renderer: renderer
    });
  } else if (field.display === DISPLAYS[FIELDS.PICKER].AUTOCOMPLETE || field.display === DISPLAYS[FIELDS.PICKER].DROPDOWN) {
    return /*#__PURE__*/_jsx(Select, {
      select: field,
      onChange: onChange,
      onBlur: onBlur,
      tabIndex: tabIndex,
      errors: errors,
      alerts: alerts,
      renderer: renderer
    });
  } else if (field.display === DISPLAYS[FIELDS.PICKER].RADIO) {
    return /*#__PURE__*/_jsx(Radio, {
      radio: field,
      onChange: onChange,
      onBlur: onBlur,
      tabIndex: tabIndex,
      errors: errors,
      alerts: alerts,
      renderer: renderer
    });
  } else if (field.display === DISPLAYS[FIELDS.PICKER].CHECKBOX) {
    return /*#__PURE__*/_jsx(Checkbox, {
      checkbox: field,
      onChange: onChange,
      onBlur: onBlur,
      tabIndex: tabIndex,
      errors: errors,
      alerts: alerts,
      renderer: renderer
    });
  } else if (field.display === DISPLAYS[FIELDS.PICKER].BUTTON_INLINE) {
    return /*#__PURE__*/_jsx(InlineButton, {
      inlineButton: field,
      onChange: onChange,
      onBlur: onBlur,
      tabIndex: tabIndex,
      errors: errors,
      alerts: alerts,
      renderer: renderer
    });
  } else {
    // TODO: should be removed (backwards compatibility)
    return /*#__PURE__*/_jsx(Select, {
      select: field,
      onChange: onChange,
      onBlur: onBlur,
      tabIndex: tabIndex,
      errors: errors,
      alerts: alerts,
      renderer: renderer
    });
  }
};

export default PickerField;
